API docs for “spamfighter.core.storage.test.test_dbm.DBMStorageTestCase”

# Class s.c.s.t.t.DBMStorageTestCase(unittest.TestCase, ExpirableStorageTestMixin):

Part of spamfighter.core.storage.test.test_dbm View Source View In Hierarchy

Тест на `spamfighter.core.storage.dbm.DBMStorage`.

Method | setUp | Undocumented
Method | tearDown | Undocumented
Method | testInterface | Undocumented

Inherited from ExpirableStorageTestMixin:

Method | testGetNotFound | Undocumented
Method | testGetOk | Undocumented
Method | testGetExpired | Undocumented
Method | testAdd | Undocumented
Method | testAppendNotFound | Undocumented
Method | testAppendTypeError1 | Undocumented
Method | testAppendTypeError2 | Undocumented
Method | testAppend | Undocumented
Method | testIncrNotFound | Undocumented
Method | testIncrTypeError1 | Undocumented
Method | testIncrTypeError2 | Undocumented
Method | testIncr | Undocumented
Method | testDeleteNotFound | Undocumented
Method | testDelete | Undocumented
Method | testSetUnlimited | Undocumented

def setUp(self): (source)
overrides spamfighter.core.storage.test.base.ExpirableStorageTestMixin.setUp
Undocumented
def tearDown(self): (source)
overrides spamfighter.core.storage.test.base.ExpirableStorageTestMixin.tearDown
Undocumented
def testInterface(self): (source)
Undocumented